@@ -30,9 +30,9 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <getopt.h>
-#include <stdarg.h>
 
 #include "acpid.h"
+#include "log.h"
 #include "event.h"
 #include "connection_list.h"
 #include "proc.h"
@@ -254,6 +254,7 @@ handle_cmdline(int *argc, char ***argv)
 		case 'd':
 			foreground = 1;
 			acpid_debug++;
+            log_debug_to_stderr = 1;
 			break;
 		case 'e':
 			eventfile = optarg;
@@ -468,33 +469,6 @@ reload_conf(int sig __attribute__((unused)))
 	acpid_read_conf(confdir);
 }
 
-int
-#ifdef __GNUC__
-__attribute__((format(printf, 2, 3)))
-#endif
-acpid_log(int level, const char *fmt, ...)
-{
-	va_list args;
-
-	if (level == LOG_DEBUG) {
-		/* if "-d" has been specified */
-		if (acpid_debug) {
-			/* send debug output to stderr */
-			va_start(args, fmt);
-			vfprintf(stderr, fmt, args);
-			va_end(args);
-
-            fprintf(stderr, "\n");
-		}
-	} else {
-		va_start(args, fmt);
-		vsyslog(level, fmt, args);
-		va_end(args);
-	}
-
-	return 0;
-}
-
 int
 locked()
 {
